@@ -187,7 +187,7 @@ def _lin_gdp(update_loc: Union[str, PathLike, Engine,
 
     data_uyu = national_accounts(update_loc=update_loc, only_get=only_get_na)[
         "gdp_cur_nsa"]
-    data_uyu = transform.rolling(data_uyu, periods=4, operation="sum")
+    data_uyu = transform.rolling(data_uyu, window=4, operation="sum")
     data_usd = transform.convert_usd(data_uyu,
                                      update_loc=update_loc,
                                      only_get=only_get)
@@ -199,21 +199,21 @@ def _lin_gdp(update_loc: Union[str, PathLike, Engine,
 
     results = []
     for table, gdp in zip(["NGDP", "NGDPD"], data):
-        table_url = (f"https://www.imf.org/external/pubs/ft/weo/2020/01/weodat"
-                     f"a/weorept.aspx?sy={last_year - 1}&ey={last_year + 1}"
-                     f"&scsm=1&ssd=1&sort=country&ds=.&br=1&pr1.x=27&pr1.y=9&c"
-                     f"=298&s={table}&grp=0&a=")
-        imf_data = pd.to_numeric(pd.read_html(table_url)[4].iloc[2, [5, 6, 7]])
+        table_url = (f"https://www.imf.org/en/Publications/WEO/weo-database/"
+                     f"2020/October/weo-report?c=298,&s={table},&sy="
+                     f"{last_year - 1}&ey={last_year + 1}&ssm=0&scsm=1&scc=0&"
+                     f"ssd=1&ssc=0&sic=0&sort=country&ds=.&br=1")
+        imf_data = pd.to_numeric(pd.read_html(table_url)[0].iloc[0, [5, 6, 7]])
         imf_data = imf_data.reset_index(drop=True)
         fcast = (gdp.loc[[dt.datetime(last_year - 1, 12, 31)]].
                  multiply(imf_data.iloc[1]).divide(imf_data.iloc[0]))
         fcast = fcast.rename(index={dt.datetime(last_year - 1, 12, 31):
-                                    dt.datetime(last_year, 12, 31)})
+                                        dt.datetime(last_year, 12, 31)})
         next_fcast = (gdp.loc[[dt.datetime(last_year - 1, 12, 31)]].
                       multiply(imf_data.iloc[2]).divide(imf_data.iloc[0]))
         next_fcast = next_fcast.rename(
             index={dt.datetime(last_year - 1, 12, 31):
-                   dt.datetime(last_year + 1, 12, 31)}
+                       dt.datetime(last_year + 1, 12, 31)}
         )
         fcast = fcast.append(next_fcast)
         gdp = gdp.append(fcast)
@@ -285,7 +285,7 @@ def industrial_production(update_loc: Union[str, PathLike,
             return output
     try:
         raw = pd.read_excel(urls["industrial_production"]["dl"]["main"],
-                            skiprows=4, usecols="B:EM")
+                            skiprows=4, usecols="B:EM", engine="openpyxl")
     except URLError as err:
         if "SSL: CERTIFICATE_VERIFY_FAILED" in str(err):
             certificate = Path(get_project_root(), "utils", "files",
@@ -293,11 +293,12 @@ def industrial_production(update_loc: Union[str, PathLike,
             r = requests.get(urls["industrial_production"]["dl"]["main"],
                              verify=certificate)
             raw = pd.read_excel(BytesIO(r.content),
-                                    skiprows=4, usecols="B:EM")
+                                skiprows=4, usecols="B:EM")
         else:
             raise err
     proc = raw.dropna(how="any", subset=["Mes"]).dropna(thresh=100, axis=1)
-    output = proc[~proc["Mes"].str.contains("Prom")].drop("Mes", axis=1)
+    output = proc[~proc["Mes"].str.contains("PROM|Prom", 
+                                            regex=True)].drop("Mes", axis=1)
     output.index = pd.date_range(start="2002-01-31", freq="M",
                                  periods=len(output))
     output.columns = (["Industrias manufactureras",
@@ -355,7 +356,7 @@ def core_industrial(update_loc: Union[str, PathLike, Engine,
         Label for SQL indexes.
     only_get : bool, default True
         If True, don't download data, retrieve what is available from
-        ``update_loc`` for the commodity index.
+        ``update_loc``.
 
     Returns
     -------
@@ -366,7 +367,7 @@ def core_industrial(update_loc: Union[str, PathLike, Engine,
                                  only_get=only_get)
     try:
         weights = pd.read_excel(urls["core_industrial"]["dl"]["weights"],
-                                skiprows=3).dropna(how="all")
+                                skiprows=3, engine="openpyxl").dropna(how="all")
     except URLError as err:
         if "SSL: CERTIFICATE_VERIFY_FAILED" in str(err):
             certificate = Path(get_project_root(), "utils", "files",
@@ -381,14 +382,14 @@ def core_industrial(update_loc: Union[str, PathLike, Engine,
                                       "Unnamed: 6": "Pond. agrupación",
                                       "Unnamed: 7": "Pond. clase"})
     other_foods = (
-        weights.loc[weights["clase"] == 1549]["Pond. clase"].values[0]
-        * weights.loc[(weights["agrupacion"] == 154) &
-                      (weights["clase"] == 0)][
-            "Pond. agrupación"].values[0]
-        * weights.loc[(weights["division"] == 15) &
+            weights.loc[weights["clase"] == 1549]["Pond. clase"].values[0]
+            * weights.loc[(weights["agrupacion"] == 154) &
+                          (weights["clase"] == 0)][
+                "Pond. agrupación"].values[0]
+            * weights.loc[(weights["division"] == 15) &
                           (weights["agrupacion"] == 0)][
                 "Pond. división"].values[0]
-        / 1000000)
+            / 1000000)
     pulp = (weights.loc[weights["clase"] == 2101]["Pond. clase"].values[0]
             * weights.loc[(weights["division"] == 21) &
                           (weights["agrupacion"] == 0)][
@@ -406,8 +407,8 @@ def core_industrial(update_loc: Union[str, PathLike, Engine,
     core = pd.concat([core], keys=["Núcleo industrial"],
                      names=["Indicador"], axis=1)
     output = pd.concat([output, core], axis=1)
-    output = transform.base_index(output, start_date="2006-01-01",
-                                  end_date="2006-12-31")
+    output = transform.rebase(output, start_date="2006-01-01",
+                              end_date="2006-12-31")
 
     if save_loc is not None:
         ops._io(operation="save", data_loc=save_loc,
@@ -472,7 +473,8 @@ def cattle(
     with open(temp, "wb") as f:
         r = requests.get(urls["cattle"]["dl"]["main"])
         f.write(r.content)
-    output = pd.read_excel(temp, skiprows=8, usecols="A,C:H", index_col=0)
+    output = pd.read_excel(temp, skiprows=8, usecols="A,C:H", index_col=0,
+                           engine="openpyxl")
 
     if update_loc is not None:
         previous_data = ops._io(
@@ -628,7 +630,8 @@ def cement(
             return output
 
     output = pd.read_excel(urls["cement"]["dl"]["main"], skiprows=2,
-                           usecols="B:E", index_col=0, skipfooter=1)
+                           usecols="B:E", index_col=0, skipfooter=1,
+                           engine="openpyxl")
     output.index = output.index + MonthEnd(0)
     output.columns = ["Exportaciones", "Mercado interno", "Total"]
 
@@ -711,7 +714,7 @@ def diesel(
     with open(temp_rar, "wb") as f:
         r = requests.get(urls["diesel"]["dl"]["main"])
         soup = BeautifulSoup(r.content, features="lxml")
-        rar_url = soup.find_all(href=re.compile("venta[%20a-z]+oil"))[0]
+        rar_url = soup.find_all(href=re.compile("gas%20oil"))[0]
         f.write(requests.get(rar_url["href"]).content)
     with tempfile.TemporaryDirectory() as temp_dir:
         patoolib.extract_archive(temp_rar, outdir=temp_dir, verbosity=-1)
@@ -803,7 +806,7 @@ def gasoline(
     with open(temp_rar, "wb") as f:
         r = requests.get(urls["gasoline"]["dl"]["main"])
         soup = BeautifulSoup(r.content, features="lxml")
-        rar_url = soup.find_all(href=re.compile("venta[%20a-z]+gasolina"))[0]
+        rar_url = soup.find_all(href=re.compile("gasolina"))[0]
         f.write(requests.get(rar_url["href"]).content)
     with tempfile.TemporaryDirectory() as temp_dir:
         patoolib.extract_archive(temp_rar, outdir=temp_dir, verbosity=-1)
@@ -895,7 +898,7 @@ def electricity(
     with open(temp_rar, "wb") as f:
         r = requests.get(urls["electricity"]["dl"]["main"])
         soup = BeautifulSoup(r.content, features="lxml")
-        rar_url = soup.find_all(href=re.compile("facturaci[%A-z0-9]+sector"))[
+        rar_url = soup.find_all(href=re.compile("Facturaci[%A-z0-9]+sector"))[
             0]
         f.write(requests.get(rar_url["href"]).content)
     with tempfile.TemporaryDirectory() as temp_dir:
