@@ -1,3 +1,4 @@
+import sys
 import datetime as dt
 import re
 import warnings
@@ -90,10 +91,10 @@ def balance(update_loc: Union[str, PathLike, Engine, Connection, None] = None,
     soup = BeautifulSoup(response.content, "html.parser")
     links = soup.find_all(href=re.compile("\\.xlsx$"))
     link = links[0]["href"]
-    xls = pd.ExcelFile(link)
+    xls = pd.ExcelFile(link, engine="openpyxl")
     output = {}
     for sheet, meta in fiscal_sheets.items():
-        data = (pd.read_excel(xls, sheet_name=sheet).
+        data = (pd.read_excel(xls, sheet_name=sheet, engine="openpyxl").
                 dropna(axis=0, thresh=4).dropna(axis=1, thresh=4).
                 transpose().set_index(2, drop=True))
         data.columns = data.iloc[0]
@@ -138,8 +139,7 @@ def tax_revenue(
         save_loc: Union[str, PathLike, Engine, Connection, None] = None,
         name: str = "taxes",
         index_label: str = "index",
-        only_get: bool = False,
-        **kwargs) -> pd.DataFrame:
+        only_get: bool = False) -> pd.DataFrame:
     """
     Get tax revenues data.
 
@@ -191,7 +191,7 @@ def tax_revenue(
     output.index = output.index + MonthEnd(0)
     output.columns = taxes_columns
     output = output.div(1000000)
-    latest = _get_taxes_from_pdf(output, **kwargs)
+    latest = _get_taxes_from_pdf(output)
     output = pd.concat([output, latest], sort=False)
     output = output.loc[~output.index.duplicated(keep="first")]
 
@@ -215,8 +215,7 @@ def tax_revenue(
     return output
 
 
-def _get_taxes_from_pdf(excel_data: pd.DataFrame,
-                        driver: WebDriver = None) -> pd.DataFrame:
+def _get_taxes_from_pdf(excel_data: pd.DataFrame) -> pd.DataFrame:
     extra_url = ",O,es,0,"
     last_month = excel_data.index[-1].month
     last_year = excel_data.index[-1].year
@@ -224,23 +223,24 @@ def _get_taxes_from_pdf(excel_data: pd.DataFrame,
         reports_year = [last_year + 1]
     else:
         reports_year = [last_year, last_year + 1]
-    if driver is None:
-        driver = _build()
     data = []
     for year in reports_year:
         url = f"{urls['taxes']['dl']['report']}{year}{extra_url}"
-        try:
-            driver.get(url)
-        except WebDriverException:
+        r = requests.get(url)
+        pdf_urls = re.findall("afiledownload\?2,4,1851,O,S,0,[0-9]+"
+                              "%[0-9A-z]{3}%[0-9A-z]{3}%3B108,", r.text)
+        pdf_urls = list(dict.fromkeys(pdf_urls))
+        if len(pdf_urls) == 0:
             continue
-        soup = BeautifulSoup(driver.page_source, "html.parser")
-        pdfs = soup.find_all("a", class_=re.compile("TitleStyle"),
-                             text=re.compile("recaudación"))
         dates = pd.date_range(start=dt.datetime(year, 1, 1), freq="M",
-                              periods=len(pdfs))
-        for pdf, date in zip(pdfs, dates):
-            with NamedTemporaryFile(suffix=".pdf") as f:
-                r = requests.get(f"https://www.dgi.gub.uy/wdgi/{pdf['href']}")
+                              periods=len(pdf_urls))
+        if sys.platform == "win32":
+            delete = False
+        else:
+            delete = True
+        for pdf, date in zip(pdf_urls, dates):
+            with NamedTemporaryFile(suffix=".pdf", delete=delete) as f:
+                r = requests.get(f"https://www.dgi.gub.uy/wdgi/{pdf}")
                 f.write(r.content)
                 with warnings.catch_warnings():
                     warnings.filterwarnings("ignore", category=PdfReadWarning)
@@ -275,7 +275,6 @@ def _get_taxes_from_pdf(excel_data: pd.DataFrame,
                     'Impuesto de Educación Primaria',
                     'Recaudación Total de la DGI']
                 data.append(table)
-    driver.quit()
     output = pd.concat(data)
 
     return output
@@ -360,9 +359,10 @@ def public_debt(update_loc: Union[str, PathLike,
     gps.columns = colnames
 
     nfps_raw = pd.read_excel(xls, sheet_name="SPNM bruta",
-                             usecols="B:O", index_col=0,
-                             skiprows=(dt.datetime.now().year - 1999) * 8 + 18)
-    nfps = nfps_raw.dropna(how="any")
+                             usecols="B:O", index_col=0)
+    loc = nfps_raw.index.get_loc("9. Deuda Bruta del Sector Público no "
+                                 "monetario por plazo y  moneda.")
+    nfps = nfps_raw.iloc[loc + 5:, :].dropna(how="any")
     nfps.index = pd.date_range(start="1999-12-31", periods=len(nfps),
                                freq="Q-DEC")
     nfps_extra_raw = pd.read_excel(xls, sheet_name="SPNM bruta",
@@ -449,7 +449,7 @@ def net_public_debt(update_loc: Union[str, PathLike, Engine,
         Label for SQL indexes.
     only_get : bool, default True
         If True, don't download data, retrieve what is available from
-        ``update_loc`` for the commodity index.
+        ``update_loc``.
 
     Returns
     -------
@@ -467,7 +467,7 @@ def net_public_debt(update_loc: Union[str, PathLike, Engine,
         update_loc=update_loc, save_loc=save_loc,
         only_get=only_get).loc[:,
                                ["Obligaciones en ME con el sector financiero"]]
-    deposits = (transform.resample(deposits, target="Q-DEC", operation="end")
+    deposits = (transform.resample(deposits, rule="Q-DEC", operation="last")
                 .reindex(gross_debt.index).squeeze())
     output = gross_debt.add(assets).add(deposits, axis=0).dropna()
 
@@ -514,7 +514,7 @@ def balance_fss(update_loc: Union[str, PathLike, Engine,
         Label for SQL indexes.
     only_get : bool, default True
         If True, don't download data, retrieve what is available from
-        ``update_loc`` for the commodity index.
+        ``update_loc``.
 
     Returns
     -------
