@@ -1,4 +1,4 @@
-from pathlib import Path
+﻿from pathlib import Path
 from io import BytesIO
 from os import PathLike
 from typing import Union
@@ -69,7 +69,7 @@ def labor_rates(update_loc: Union[str, PathLike,
             return output
 
     try:
-        labor_raw = pd.read_excel(urls["labor"]["dl"]["main"],
+        labor_raw = pd.read_excel(urls["labor"]["dl"]["main"], engine="openpyxl",
                                   skiprows=39).dropna(axis=0, thresh=2)
     except URLError as err:
         if "SSL: CERTIFICATE_VERIFY_FAILED" in str(err):
@@ -91,7 +91,7 @@ def labor_rates(update_loc: Union[str, PathLike,
                      "Tasa de empleo: hombres", "Tasa de empleo: mujeres",
                      "Tasa de desempleo: total", "Tasa de desempleo: hombres",
                      "Tasa de desempleo: mujeres"]
-    missing = pd.read_excel(urls["labor"]["dl"]["missing"],
+    missing = pd.read_excel(urls["labor"]["dl"]["missing"], engine="openpyxl",
                             index_col=0, header=0).iloc[:, :9]
     missing.columns = labor.columns
     labor = labor.append(missing)
@@ -171,8 +171,8 @@ def nominal_wages(update_loc: Union[str, PathLike,
             return output
     try:
         historical = pd.read_excel(urls["wages"]["dl"]["historical"],
-                                   skiprows=8, usecols="A:B")
-        current = pd.read_excel(urls["wages"]["dl"]["current"],
+                                   skiprows=8, usecols="A:B", engine="openpyxl")
+        current = pd.read_excel(urls["wages"]["dl"]["current"], engine="openpyxl",
                                 skiprows=8, usecols="A,C:D")
     except URLError as err:
         if "SSL: CERTIFICATE_VERIFY_FAILED" in str(err):
@@ -272,9 +272,9 @@ def hours(update_loc: Union[str, PathLike,
 
     try:
         raw = pd.read_excel(urls["hours"]["dl"]["main"], sheet_name="Mensual",
-                            skiprows=5, index_col=0).dropna(how="all")
+                            skiprows=5, index_col=0, engine="openpyxl").dropna(how="all")
         prev_hours = pd.read_excel(urls["hours"]["dl"]["historical"], index_col=0,
-                                   skiprows=8).dropna(how="all").iloc[:, [0]]
+                                   skiprows=8, engine="openpyxl").dropna(how="all").iloc[:, [0]]
     except URLError as err:
         if "SSL: CERTIFICATE_VERIFY_FAILED" in str(err):
             certificate = Path(get_project_root(), "utils", "files",
@@ -311,11 +311,6 @@ def hours(update_loc: Union[str, PathLike,
     prev_hours.columns = ["Total"]
     output = prev_hours.append(output, sort=False)
 
-    missing = pd.read_excel(urls["hours"]["dl"]["missing"],
-                            index_col=0, header=0).iloc[:, [9]]
-    missing.columns = ["Total"]
-    output = output.append(missing, sort=False)
-
     if update_loc is not None:
         previous_data = ops._io(operation="update",
                                 data_loc=update_loc,
@@ -370,7 +365,7 @@ def rates_people(update_loc: Union[str, PathLike, Engine,
         Label for SQL indexes.
     only_get : bool, default True
         If True, don't download data, retrieve what is available from
-        ``update_loc`` for the commodity index.
+        ``update_loc``.
 
     Returns
     -------
@@ -383,16 +378,16 @@ def rates_people(update_loc: Union[str, PathLike, Engine,
     try:
         act_5000 = pd.read_excel(urls["rates_people"]["dl"]["act_5000"],
                                  sheet_name="Mensual", index_col=0, skiprows=8,
-                                 usecols="A:B").dropna(how="any")
+                                 usecols="A:B", engine="openpyxl").dropna(how="any")
         emp_5000 = pd.read_excel(urls["rates_people"]["dl"]["emp_5000"],
                                  sheet_name="Mensual", index_col=0, skiprows=8,
-                                 usecols="A:B").dropna(how="any")
+                                 usecols="A:B", engine="openpyxl").dropna(how="any")
         des_5000 = pd.read_excel(urls["rates_people"]["dl"]["des_5000"],
                                  sheet_name="Mensual", index_col=0, skiprows=7,
-                                 usecols="A:B").dropna(how="any")
+                                 usecols="A:B", engine="openpyxl").dropna(how="any")
         working_age = pd.read_excel(urls["rates_people"]["dl"]["population"],
                                     skiprows=7, index_col=0,
-                                    nrows=92).dropna(how="all")
+                                    nrows=92, engine="openpyxl").dropna(how="all")
     except URLError as err:
         if "SSL: CERTIFICATE_VERIFY_FAILED" in str(err):
             certificate = Path(get_project_root(), "utils", "files",
@@ -481,7 +476,7 @@ def real_wages(update_loc: Union[str, PathLike, Engine,
         Label for SQL indexes.
     only_get : bool, default True
         If True, don't download data, retrieve what is available from
-        ``update_loc`` for the commodity index.
+        ``update_loc``.
 
     Returns
     -------
@@ -497,7 +492,7 @@ def real_wages(update_loc: Union[str, PathLike, Engine,
     output = transform.convert_real(wages, update_loc=update_loc,
                                     only_get=only_get)
 
-    output = transform.base_index(output, start_date="2008-07-31")
+    output = transform.rebase(output, start_date="2008-07-31")
 
     if save_loc is not None:
         ops._io(operation="save", data_loc=save_loc,
