@@ -1,3 +1,4 @@
+import logging
 import shutil
 import datetime as dt
 from os import listdir, remove, path
@@ -45,8 +46,8 @@ def test_prices_inflation():
     remove_clutter()
     prices = session.get(dataset="cpi").dataset
     prices = prices.loc[prices.index >= "1997-03-31"]
-    prices = transform.base_index(prices, start_date="2010-12-01",
-                                  end_date="2010-12-31")
+    prices = transform.rebase(prices, start_date="2010-12-01",
+                              end_date="2010-12-31")
     compare = measures.iloc[:, [0]]
     compare.columns = prices.columns
     assert compare.equals(prices)
@@ -143,7 +144,7 @@ def test_wages():
     real_wages = session.get(dataset="real_wages").dataset
     nominal_wages = session.get(dataset="wages").dataset
     compare = transform.convert_real(nominal_wages, update_loc=TEST_CON)
-    compare = transform.base_index(compare, start_date="2008-07-31")
+    compare = transform.rebase(compare, start_date="2008-07-31")
     compare.columns = real_wages.columns
     assert compare.equals(real_wages)
 
@@ -307,6 +308,160 @@ def test_bond_index():
     remove_clutter()
 
 
+def test_global_gdp():
+    remove_clutter()
+    session = Session(location=TEST_CON)
+    assert isinstance(session, Session)
+    assert isinstance(session.dataset, pd.DataFrame)
+    global_gdp = session.get_custom(dataset="global_gdp").dataset
+    assert global_gdp.index[0] == dt.datetime(1947, 3, 31)
+    assert len(global_gdp.columns) == 4
+    remove_clutter()
+
+
+def test_global_stocks():
+    remove_clutter()
+    session = Session(location=TEST_CON)
+    assert isinstance(session, Session)
+    assert isinstance(session.dataset, pd.DataFrame)
+    stocks = session.get_custom(dataset="global_stocks").dataset
+    assert stocks.index[0] == dt.datetime(1927, 12, 30)
+    assert len(stocks.columns) == 4
+    remove_clutter()
+
+
+def test_global_policy_rates():
+    remove_clutter()
+    session = Session(location=TEST_CON)
+    assert isinstance(session, Session)
+    assert isinstance(session.dataset, pd.DataFrame)
+    policy = session.get_custom(dataset="global_policy_rates").dataset
+    assert policy.index[0] == dt.datetime(1946, 1, 1)
+    assert len(policy.columns) == 4
+    remove_clutter()
+
+
+def test_global_long_rates():
+    remove_clutter()
+    session = Session(location=TEST_CON)
+    assert isinstance(session, Session)
+    assert isinstance(session.dataset, pd.DataFrame)
+    long = session.get_custom(dataset="global_long_rates").dataset
+    assert long.index[0] == dt.datetime(1962, 1, 2)
+    assert len(long.columns) == 8
+    remove_clutter()
+
+
+def test_global_nxr():
+    remove_clutter()
+    session = Session(location=TEST_CON)
+    assert isinstance(session, Session)
+    assert isinstance(session.dataset, pd.DataFrame)
+    currencies = session.get_custom(dataset="global_nxr").dataset
+    assert currencies.index[0] == dt.datetime(1971, 1, 4)
+    assert len(currencies.columns) == 4
+    remove_clutter()
+
+
+def test_regional_gdp():
+    remove_clutter()
+    session = Session(location=TEST_CON)
+    assert isinstance(session, Session)
+    assert isinstance(session.dataset, pd.DataFrame)
+    gdp = session.get_custom(dataset="regional_gdp").dataset
+    assert gdp.index[0] == dt.datetime(1993, 3, 31)
+    assert len(gdp.columns) == 2
+    remove_clutter()
+
+
+def test_regional_monthly_gdp():
+    remove_clutter()
+    session = Session(location=TEST_CON)
+    assert isinstance(session, Session)
+    assert isinstance(session.dataset, pd.DataFrame)
+    gdp = session.get_custom(dataset="regional_monthly_gdp").dataset
+    assert gdp.index[0] == dt.datetime(2003, 1, 31)
+    assert len(gdp.columns) == 2
+    remove_clutter()
+
+
+def test_regional_cpi():
+    remove_clutter()
+    session = Session(location=TEST_CON)
+    assert isinstance(session, Session)
+    assert isinstance(session.dataset, pd.DataFrame)
+    cpi = session.get_custom(dataset="regional_cpi").dataset
+    assert cpi.index[0] == dt.datetime(1970, 1, 31)
+    assert len(cpi.columns) == 2
+    remove_clutter()
+
+
+def test_regional_embi_spreads():
+    remove_clutter()
+    session = Session(location=TEST_CON)
+    assert isinstance(session, Session)
+    assert isinstance(session.dataset, pd.DataFrame)
+    spreads = session.get_custom(dataset="regional_embi_spreads").dataset
+    assert spreads.index[0] == dt.datetime(1998, 12, 11)
+    assert len(spreads.columns) == 3
+    remove_clutter()
+
+
+def test_regional_embi_yields():
+    remove_clutter()
+    session = Session(location=TEST_CON)
+    assert isinstance(session, Session)
+    assert isinstance(session.dataset, pd.DataFrame)
+    yields = session.get_custom(dataset="regional_embi_yields").dataset
+    assert yields.index[0] == dt.datetime(1998, 12, 11)
+    assert len(yields.columns) == 3
+    remove_clutter()
+
+
+def test_regional_nxr():
+    remove_clutter()
+    session = Session(location=TEST_CON)
+    assert isinstance(session, Session)
+    assert isinstance(session.dataset, pd.DataFrame)
+    nxr = session.get_custom(dataset="regional_nxr").dataset
+    assert nxr.index[0] == dt.datetime(2002, 4, 9)
+    assert len(nxr.columns) == 3
+    remove_clutter()
+
+
+def test_regional_rxr():
+    remove_clutter()
+    session = Session(location=TEST_CON)
+    assert isinstance(session, Session)
+    assert isinstance(session.dataset, pd.DataFrame)
+    rxr = session.get_custom(dataset="regional_rxr").dataset
+    assert rxr.index[0] == dt.datetime(1970, 1, 31)
+    assert len(rxr.columns) == 2
+    remove_clutter()
+
+
+def test_regional_policy_rates():
+    remove_clutter()
+    session = Session(location=TEST_CON)
+    assert isinstance(session, Session)
+    assert isinstance(session.dataset, pd.DataFrame)
+    policy = session.get_custom(dataset="regional_policy_rates").dataset
+    assert policy.index[0] == dt.datetime(1986, 6, 4)
+    assert len(policy.columns) == 2
+    remove_clutter()
+
+
+def test_regional_stocks():
+    remove_clutter()
+    session = Session(location=TEST_CON)
+    assert isinstance(session, Session)
+    assert isinstance(session.dataset, pd.DataFrame)
+    stocks = session.get_custom(dataset="regional_stocks").dataset
+    assert stocks.index[0] == dt.datetime(2002, 4, 9)
+    assert len(stocks.columns) == 2
+    remove_clutter()
+
+
 def test_trade():
     remove_clutter()
     session = Session(location=TEST_CON)
@@ -330,8 +485,8 @@ def test_trade():
                / tb_["trade_m_orig_pri"].
                rename(columns={"Total importaciones": "Total"}))
     compare = compare.loc[:, ["Total"]]
-    compare = transform.base_index(compare, start_date="2005-01-01",
-                                   end_date="2005-12-31")
+    compare = transform.rebase(compare, start_date="2005-01-01",
+                               end_date="2005-12-31")
     compare.columns = net.columns
     assert net.equals(compare)
     remove_clutter()
@@ -364,8 +519,8 @@ def test_industrial_production():
                - indprod.loc[:, 2101] * 0.008097608)
     compare = pd.concat([compare], keys=["Núcleo industrial"],
                         names=["Indicador"], axis=1)
-    compare = transform.base_index(compare, start_date="2006-01-01",
-                                   end_date="2006-12-31")
+    compare = transform.rebase(compare, start_date="2006-01-01",
+                               end_date="2006-12-31")
     compare.columns = core.columns
     assert core.round(2).equals(compare.round(2))
     remove_clutter()
@@ -418,23 +573,25 @@ def test_save():
 def test_logging(caplog):
     remove_clutter()
     caplog.clear()
-    Session(location=TEST_DIR, log="test")
-    assert path.isfile(path.join(TEST_DIR, "test.log"))
-    remove_clutter()
+    s = Session(location=TEST_DIR, log="test")
+    test_path = path.join(TEST_DIR, "test.log")
+    assert path.isfile(test_path)
+    logging.shutdown()
     caplog.clear()
-    Session(location=TEST_DIR, log=2)
-    assert path.isfile(path.join(TEST_DIR, "info.log"))
-    remove_clutter()
+    s = Session(location=TEST_DIR, log=2)
+    info_path = path.join(TEST_DIR, "info.log")
+    assert path.isfile(info_path)
+    logging.shutdown()
     caplog.clear()
     with pytest.raises(ValueError):
         Session(location=TEST_DIR, log=5)
-    remove_clutter()
     caplog.clear()
+    remove_clutter()
     Session(location=TEST_DIR, log=1)
     assert "Logging method: console" in caplog.text
     assert "Logging method: console and file" not in caplog.text
     assert not path.isfile(path.join(TEST_DIR, "info.log"))
     caplog.clear()
-    remove_clutter()
     Session(location=TEST_DIR, log=0)
     assert caplog.text == ""
+    logging.shutdown()
