@@ -32,25 +32,25 @@ def dummy_df(freq, periods=200, area="Test", currency="Test",
 def test_diff():
     data_m = dummy_df(freq="M")
     session = Session(location=TEST_CON, dataset=data_m)
-    trf_last = session.chg_diff(operation="diff", period_op="last").dataset
+    trf_last = session.chg_diff(operation="diff", period="last").dataset
     trf_last.columns = data_m.columns
     assert trf_last.equals(data_m.diff(periods=1))
     data_q1 = dummy_df(freq="Q-DEC")
     data_q2 = dummy_df(freq="Q-DEC")
     data_dict = {"data_q1": data_q1, "data_q2": data_q2}
     session = Session(location=TEST_CON, dataset=data_dict, inplace=True)
-    trf_inter = session.chg_diff(operation="diff", period_op="inter").dataset
+    trf_inter = session.chg_diff(operation="diff", period="inter").dataset
     trf_inter["data_q1"].columns = trf_inter[
         "data_q2"].columns = data_q1.columns
     assert trf_inter["data_q1"].equals(data_q1.diff(periods=4))
     assert trf_inter["data_q2"].equals(data_q2.diff(periods=4))
     data_a = dummy_df(freq="A", ts_type="Flow")
-    trf_annual = transform.chg_diff(data_a, operation="diff", period_op="last")
+    trf_annual = transform.chg_diff(data_a, operation="diff", period="last")
     trf_annual.columns = data_a.columns
     assert trf_annual.equals(data_a.diff(periods=1))
     data_q_annual = dummy_df(freq="Q-DEC", ts_type="Flujo")
     trf_q_annual = transform.chg_diff(data_q_annual, operation="diff",
-                                      period_op="annual")
+                                      period="annual")
     trf_q_annual.columns = data_q_annual.columns
     assert trf_q_annual.equals(data_q_annual.
                                rolling(window=4, min_periods=4).
@@ -58,7 +58,7 @@ def test_diff():
                                diff(periods=4))
     data_q_annual = dummy_df(freq="Q-DEC", ts_type="Stock")
     trf_q_annual = transform.chg_diff(data_q_annual, operation="diff",
-                                      period_op="annual")
+                                      period="annual")
     trf_q_annual.columns = data_q_annual.columns
     assert trf_q_annual.equals(data_q_annual.diff(periods=4))
     with pytest.raises(ValueError):
@@ -69,19 +69,19 @@ def test_diff():
 def test_chg():
     data_m = dummy_df(freq="M")
     session = Session(location=TEST_CON, dataset=data_m, inplace=True)
-    trf_last = session.chg_diff(operation="chg", period_op="last").dataset
+    trf_last = session.chg_diff(operation="chg", period="last").dataset
     trf_last.columns = data_m.columns
     assert trf_last.equals(data_m.pct_change(periods=1).multiply(100))
     data_m = dummy_df(freq="M")
     session = Session(location=TEST_CON, dataset=data_m, inplace=True)
-    trf_last = session.chg_diff(operation="chg", period_op="last").dataset
+    trf_last = session.chg_diff(operation="chg", period="last").dataset
     trf_last.columns = data_m.columns
     assert trf_last.equals(data_m.pct_change(periods=1).multiply(100))
     data_q1 = dummy_df(freq="Q-DEC")
     data_q2 = dummy_df(freq="Q-DEC")
     data_dict = {"data_q1": data_q1, "data_q2": data_q2}
     session = Session(location=TEST_CON, dataset=data_dict)
-    trf_inter = session.chg_diff(operation="chg", period_op="inter").dataset
+    trf_inter = session.chg_diff(operation="chg", period="inter").dataset
     trf_inter["data_q1"].columns = trf_inter[
         "data_q2"].columns = data_q1.columns
     assert trf_inter["data_q1"].equals(data_q1.pct_change(periods=4).
@@ -89,12 +89,12 @@ def test_chg():
     assert trf_inter["data_q2"].equals(data_q2.pct_change(periods=4).
                                        multiply(100))
     data_a = dummy_df(freq="A", ts_type="Flow")
-    trf_annual = transform.chg_diff(data_a, operation="chg", period_op="last")
+    trf_annual = transform.chg_diff(data_a, operation="chg", period="last")
     trf_annual.columns = data_a.columns
     assert trf_annual.equals(data_a.pct_change(periods=1).multiply(100))
     data_q_annual = dummy_df(freq="Q-DEC", ts_type="Flujo")
     trf_q_annual = transform.chg_diff(data_q_annual, operation="chg",
-                                      period_op="annual")
+                                      period="annual")
     trf_q_annual.columns = data_q_annual.columns
     assert trf_q_annual.equals(data_q_annual.
                                rolling(window=4, min_periods=4).
@@ -121,45 +121,45 @@ def test_rolling():
                                                        min_periods=12).sum())
     with pytest.warns(UserWarning):
         data_wrong = dummy_df(freq="M", ts_type="Stock")
-        transform.rolling(data_wrong, periods=4, operation="average")
+        transform.rolling(data_wrong, window=4, operation="mean")
 
 
 def test_resample():
     data_m = dummy_df(freq="M", periods=204, ts_type="Flujo", cumperiods=2)
     session = Session(location=TEST_CON, dataset=data_m)
-    trf_none = session.resample(target="Q-DEC", operation="sum").dataset
+    trf_none = session.resample(rule="Q-DEC", operation="sum").dataset
     trf_none.columns = data_m.columns
     assert trf_none.equals(data_m.resample("Q-DEC").sum())
     data_q1 = dummy_df(freq="Q", ts_type="Flujo")
     data_q2 = dummy_df(freq="Q", ts_type="Flujo")
     data_dict = {"data_q1": data_q1, "data_q2": data_q2}
     session = Session(location=TEST_CON, dataset=data_dict, inplace=True)
-    trf_inter = session.resample(target="A-DEC", operation="average").dataset
+    trf_inter = session.resample(rule="A-DEC", operation="mean").dataset
     trf_inter["data_q1"].columns = trf_inter[
         "data_q2"].columns = data_q1.columns
     assert trf_inter["data_q1"].equals(data_q1.resample("A-DEC").mean())
     assert trf_inter["data_q2"].equals(data_q2.resample("A-DEC").mean())
     data_m = dummy_df(freq="Q-DEC")
-    trf_none = transform.resample(data_m, target="M", operation="upsample")
+    trf_none = transform.resample(data_m, rule="M", operation="upsample")
     trf_none.columns = data_m.columns
     assert trf_none.equals(data_m.resample("M").interpolate("linear"))
     data_m = dummy_df(freq="Q-DEC")
-    trf_none = transform.resample(data_m, target="A-DEC", operation="end")
+    trf_none = transform.resample(data_m, rule="A-DEC", operation="last")
     trf_none.columns = data_m.columns
     assert trf_none.equals(data_m.asfreq(freq="A-DEC"))
     data_m = dummy_df(freq="Q-DEC")
     data_m.columns.set_levels(["-"], level=2, inplace=True)
-    trf_none = transform.resample(data_m, target="M", operation="upsample")
+    trf_none = transform.resample(data_m, rule="M", operation="upsample")
     trf_none.columns = data_m.columns
     assert trf_none.equals(data_m.resample("M").interpolate("linear"))
     data_m = dummy_df(freq="Q-DEC")
     data_m.columns.set_levels(["-"], level=2, inplace=True)
-    trf_none = transform.resample(data_m, target="A-DEC", operation="end")
+    trf_none = transform.resample(data_m, rule="A-DEC", operation="last")
     trf_none.columns = data_m.columns
     assert trf_none.equals(data_m.asfreq(freq="A-DEC"))
     with pytest.raises(ValueError):
         data_m = dummy_df(freq="M", periods=204, ts_type="Flujo")
-        transform.resample(data_m, target="Q-DEC", operation="wrong")
+        transform.resample(data_m, rule="Q-DEC", operation="wrong")
 
 
 def test_decompose():
@@ -179,127 +179,147 @@ def test_decompose():
                       multiply(np.random.uniform(1.04, 1.06)))
     noise = np.random.normal(0, 1, 100)
     df["Real"] = df["Real"] + noise
+    metadata._set(df, seas_adj="NSA")
     session = Session(location=TEST_CON, dataset=df[["Real"]])
-    trend, seas = session.decompose(flavor="both", trading=True,
-                                    outlier=True, fallback="loess",
-                                    ignore_warnings=False).dataset
+    decomp = session.decompose(component="both", trading=True,
+                               outlier=True, fallback="loess",
+                               ignore_warnings=False).dataset
+    trend, seas = decomp["trend"], decomp["seas"]
     trend.columns, seas.columns = ["Trend"], ["Seas"]
     out = pd.concat([df, trend, seas], axis=1)
+    out.columns = ["Exponential", "Real", "Trend", "Seas"]
+    metadata._set(out, seas_adj="NSA")
     std = out.std()
-    assert std["Real"] >= std["Seas"]
-    assert std["Real"] >= std["Trend"]
+    assert std["Real"].values >= std["Seas"].values
+    assert std["Real"].values >= std["Trend"].values
     session = Session(location=TEST_CON, dataset=df[["Real"]], inplace=True)
-    trend, seas = session.decompose(flavor="both", trading=False,
+    decomp = session.decompose(component="both", trading=False,
                                     outlier=True, fallback="loess").dataset
+    trend, seas = decomp["trend"], decomp["seas"]
     trend.columns, seas.columns = ["Trend"], ["Seas"]
     out = pd.concat([df, trend, seas], axis=1)
+    out.columns = ["Exponential", "Real", "Trend", "Seas"]
+    metadata._set(out, seas_adj="NSA")
     std = out.std()
-    assert std["Real"] >= std["Seas"]
-    assert std["Real"] >= std["Trend"]
+    assert std["Real"].values >= std["Seas"].values
+    assert std["Real"].values >= std["Trend"].values
     session = Session(location=TEST_CON, dataset=df[["Real"]])
-    trend, seas = session.decompose(flavor="both", trading=False,
+    decomp = session.decompose(component="both", trading=False,
                                     outlier=False, fallback="ma",
                                     ignore_warnings=False).dataset
+    trend, seas = decomp["trend"], decomp["seas"]
     trend.columns, seas.columns = ["Trend"], ["Seas"]
     out = pd.concat([df, trend, seas], axis=1)
+    out.columns = ["Exponential", "Real", "Trend", "Seas"]
+    metadata._set(out, seas_adj="NSA")
     std = out.std()
-    assert std["Real"] >= std["Seas"]
-    assert std["Real"] >= std["Trend"]
+    assert std["Real"].values >= std["Seas"].values
+    assert std["Real"].values >= std["Trend"].values
     session = Session(location=TEST_CON, dataset=df[["Real"]])
-    trend, seas = session.decompose(flavor="both", trading=True,
-                                    outlier=False, fallback="ma").dataset
+    decomp = session.decompose(component="both", trading=True,
+                               outlier=False, fallback="ma").dataset
+    trend, seas = decomp["trend"], decomp["seas"]
     trend.columns, seas.columns = ["Trend"], ["Seas"]
     out = pd.concat([df, trend, seas], axis=1)
+    out.columns = ["Exponential", "Real", "Trend", "Seas"]
+    metadata._set(out, seas_adj="NSA")
     std = out.std()
-    assert std["Real"] >= std["Seas"]
-    assert std["Real"] >= std["Trend"]
+    assert std["Real"].values >= std["Seas"].values
+    assert std["Real"].values >= std["Trend"].values
     session = Session(location=TEST_CON, dataset=df[["Real"]])
-    trend = session.decompose(flavor="trend", trading=True,
+    trend = session.decompose(component="trend", trading=True,
                               outlier=False, force_x13=True).dataset
-    seas = session.decompose(flavor="seas", trading=True,
+    seas = session.decompose(component="seas", trading=True,
                              outlier=False, force_x13=True,
                              ignore_warnings=False).dataset
     trend.columns, seas.columns = ["Trend"], ["Seas"]
     out = pd.concat([df, trend, seas], axis=1)
+    out.columns = ["Exponential", "Real", "Trend", "Seas"]
+    metadata._set(out, seas_adj="NSA")
     std = out.std()
-    assert std["Real"] >= std["Seas"]
-    assert std["Real"] >= std["Trend"]
+    assert std["Real"].values >= std["Seas"].values
+    assert std["Real"].values >= std["Trend"].values
     session = Session(location=TEST_CON, dataset={"data1": df[["Real"]],
                                                   "data2": df[["Real"]]})
-    trend, seas = session.decompose(flavor="both", trading=True,
-                                    outlier=False).dataset["data1"]
+    decomp = session.decompose(component="both", trading=True,
+                               outlier=False).dataset["data1"]
+    trend, seas = decomp["trend"], decomp["seas"]
     trend.columns, seas.columns = ["Trend"], ["Seas"]
     out = pd.concat([df, trend, seas], axis=1)
+    out.columns = ["Exponential", "Real", "Trend", "Seas"]
+    metadata._set(out, seas_adj="NSA")
     std = out.std()
-    assert std["Real"] >= std["Seas"]
-    assert std["Real"] >= std["Trend"]
-    with pytest.raises(ValueError):
+    assert std["Real"].values >= std["Seas"].values
+    assert std["Real"].values >= std["Trend"].values
+    with pytest.raises(FileNotFoundError):
         session = Session(location=TEST_CON, dataset=df[["Real"]])
-        session.decompose(flavor="both", trading=True,
+        session.decompose(component="both", trading=True,
                           outlier=False, x13_binary="wrong")
     session = Session(location=TEST_CON, dataset=df[["Real"]])
-    trend = session.decompose(flavor="trend", method="loess").dataset
-    seas = session.decompose(flavor="seas", method="ma").dataset
+    trend = session.decompose(component="trend", method="loess").dataset
+    seas = session.decompose(component="seas", method="ma").dataset
     trend.columns, seas.columns = ["Trend"], ["Seas"]
     out = pd.concat([df, trend, seas], axis=1)
+    out.columns = ["Exponential", "Real", "Trend", "Seas"]
+    metadata._set(out, seas_adj="NSA")
     std = out.std()
-    assert std["Real"] >= std["Seas"]
-    assert std["Real"] >= std["Trend"]
+    assert std["Real"].values >= std["Seas"].values
+    assert std["Real"].values >= std["Trend"].values
     with pytest.raises(ValueError):
-        trend = session.decompose(flavor="trend", method="wrong").dataset
+        trend = session.decompose(component="trend", method="wrong").dataset
     with pytest.raises(ValueError):
-        trend = session.decompose(flavor="trend", method="x13",
+        trend = session.decompose(component="trend", method="x13",
                                   fallback="wrong").dataset
 
 
-def test_base_index():
+def test_rebase():
     data = dummy_df(freq="M")
     session = Session(location=TEST_CON, dataset=data)
-    base = session.base_index(start_date="2000-01-31").dataset
+    base = session.rebase(start_date="2000-01-31").dataset
     assert np.all(base.loc["2000-01-31"].values == np.array([100] * 3))
     chg = data.pct_change(periods=1).multiply(100)
     session = Session(location=TEST_CON, dataset=data, inplace=True)
-    comp = session.chg_diff(operation="chg", period_op="last").dataset
+    comp = session.chg_diff(operation="chg", period="last").dataset
     chg.columns = comp.columns
     assert chg.equals(comp)
     data = dummy_df(freq="Q-DEC")
     session = Session(location=TEST_CON, dataset={
                       "data1": data, "data2": data})
-    base = session.base_index(start_date="2000-03-31").dataset
+    base = session.rebase(start_date="2000-03-31").dataset
     assert np.all(
         base["data1"].loc["2000-03-31"].values == np.array([100] * 3))
     chg = data.pct_change(periods=1).multiply(100)
     session = Session(location=TEST_CON, dataset={
                       "data1": data, "data2": data})
-    comp = session.chg_diff(operation="chg", period_op="last").dataset["data1"]
+    comp = session.chg_diff(operation="chg", period="last").dataset["data1"]
     chg.columns = comp.columns
     assert chg.equals(comp)
     data = dummy_df(freq="M")
     session = Session(location=TEST_CON, dataset=data)
-    base = session.base_index(start_date="2000-01-31",
-                              end_date="2000-12-31").dataset
+    base = session.rebase(start_date="2000-01-31",
+                          end_date="2000-12-31").dataset
     assert np.all(base["2000-01-31":"2000-12-31"].mean().round(4).values ==
                   np.array([100] * 3, dtype="float64"))
 
 
 def test_convert():
-    data = dummy_df(freq="M", ts_type="Stock")
+    data = dummy_df(freq="M", ts_type="Stock", currency="UYU")
     session = Session(location=TEST_CON, dataset=data)
     usd = session.convert(flavor="usd").dataset
     usd.columns = data.columns
     assert np.all(abs(usd) <= abs(data))
-    data = dummy_df(freq="M", ts_type="Flujo")
+    data = dummy_df(freq="M", ts_type="Flujo", currency="UYU")
     session = Session(location=TEST_CON, dataset={
                       "data1": data, "data2": data})
     usd = session.convert(flavor="usd").dataset["data1"]
     usd.columns = data.columns
     assert np.all(abs(usd) <= abs(data))
-    data = dummy_df(freq="M")
+    data = dummy_df(freq="M", currency="UYU", inf_adj="current")
     session = Session(location=TEST_CON, dataset=data)
     real = session.convert(flavor="real", start_date="2000-01-31").dataset
     real.columns = data.columns
     assert np.all(abs(real.iloc[1:]) <= abs(data.iloc[1:]))
-    data = dummy_df(freq="M")
+    data = dummy_df(freq="M", currency="UYU", inf_adj="current")
     session = Session(location=TEST_CON, dataset={
                       "data1": data, "data2": data})
     real = session.convert(flavor="real").dataset["data1"]
@@ -330,24 +350,11 @@ def test_convert():
         session = Session(location=TEST_CON,
                           dataset=data)
         session.convert(flavor="gdp")
-    data_d = dummy_df(freq="D", periods=600, ts_type="Flujo")
+    data_d = dummy_df(freq="D", periods=600, ts_type="Flujo", currency="UYU")
     session = Session(location=TEST_CON, dataset=data_d)
     real = session.convert(flavor="real", start_date="2000-01-31")
     pcgdp = session.convert(flavor="pcgdp")
     usd = session.convert(flavor="usd")
-    data_d = dummy_df(freq="D", periods=600, ts_type="Stock", currency="USD")
-    session = Session(location=TEST_CON, dataset=data_d)
-    real = session.convert(flavor="real", start_date="2000-01-31",
-                           end_date="2000-12-31")
-    pcgdp = session.convert(flavor="pcgdp")
-    usd = session.convert(flavor="usd")
-    real_2 = session.convert(flavor="real", start_date="2000-01-31",
-                             end_date="2000-12-31")
-    assert real.dataset.equals(real_2.dataset)
-    pcgdp_2 = session.convert(flavor="pcgdp")
-    assert pcgdp.dataset.equals(pcgdp_2.dataset)
-    usd_2 = session.convert(flavor="usd")
-    assert usd.dataset.equals(usd_2.dataset)
     data_m = dummy_df(freq="M", ts_type="Flujo")
     session = Session(location=TEST_CON, dataset=data_m)
     pcgdp = session.convert(flavor="pcgdp")
